from typing import Dict

from resend import request


class Audiences:
    """Audiences API Wrapper"""

    @classmethod
    # https://resend.com/docs/api-reference/audiences/create-audience
    def create(cls, params={}) -> Dict:
        path = "/audiences"
        return request.Request(path=path, params=params, verb="post").perform()

    @classmethod
    # https://resend.com/docs/api-reference/audiences/list-audiences
    def list(cls) -> Dict:
        path = "/audiences/"
        return request.Request(path=path, params={}, verb="get").perform()

    @classmethod
    # https://resend.com/docs/api-reference/audiences/get-audience
    def get(cls, id) -> Dict:
        path = f"/audiences/{id}"
        return request.Request(path=path, params={}, verb="get").perform()

    @classmethod
    # https://resend.com/docs/api-reference/audiences/delete-audience
    def remove(cls, id="") -> Dict:
        path = f"/audiences/{id}"
        return request.Request(path=path, params={}, verb="delete").perform()



from typing import Dict

from resend import request


class Emails:
    """Emails API Wrapper"""

    @classmethod
    # https://resend.com/docs/api-reference/emails/send-email
    def send(
        cls,
        params: Dict,
    ) -> Dict:
        path = "/emails"
        return request.Request(path=path, params=params, verb="post").perform()

    @classmethod
    # https://resend.com/docs/api-reference/emails/retrieve-email
    def get(cls, email_id: str = "") -> Dict:
        path = f"/emails/{email_id}"
        return request.Request(path=path, params={}, verb="get").perform()



from typing import Dict, List

from resend import request


class Batch:
    """(Beta) Batch Email sending API Wrapper"""

    @classmethod
    # https://resend.com/docs/api-reference/emails/send-batch-emails
    def send(
        cls,
        params: List[Dict],
    ) -> List[Dict]:
        path = "/emails/batch"
        return request.Request(path=path, params=params, verb="post").perform()
